@@ -34,7 +34,7 @@ simpleostream.cpp
 "
 echo "compiling, this can take some time ..."
 cd src                         || exit 1
-cp builtparser.h parser.h      || exit 1
+cp builtparser.hpp parser.hpp  || exit 1
 cp builtparser.cpp parser.cpp  || exit 1
 cp builtlexer.cpp lexer.cpp    || exit 1
 $CPP $CPPFLAGS -o $EXE $SRCS   || exit 1
