@@ -5,7 +5,7 @@
 
 #include "debug.h"
 #include "flags.h"
-#include "parser.h"
+#include "parser.hpp"
 
 #define optargcheck if (!optarg || strlen(optarg)==0) break;
 
