@@ -2,7 +2,7 @@
 //
 // to generate dependencies:
 //
-#include "parser.h"
+#include "parser.hpp"
 #include "debug.h"
 #include "lexer.h"
 #include "line_prep.h"
